==> IO-K8s-1.000.tar.gz: IO-K8s-1.000/lib/IO/K8s/ApiextensionsApiserver/Pkg/Apis/Apiextensions/V1/CustomResourceConversion.pm <==
package IO::K8s::ApiextensionsApiserver::Pkg::Apis::Apiextensions::V1::CustomResourceConversion;
# ABSTRACT: CustomResourceConversion describes how to convert different versions of a CR.
our $VERSION = '1.000';
use IO::K8s::Resource;

k8s strategy => Str, 'required';


k8s webhook => 'Apiextensions::V1::WebhookConversion';


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::ApiextensionsApiserver::Pkg::Apis::Apiextensions::V1::CustomResourceConversion - CustomResourceConversion describes how to convert different versions of a CR.

=head1 VERSION

version 1.000

=head2 strategy

strategy specifies how custom resources are converted between versions. Allowed values are: - `"None"`: The converter only change the apiVersion and would not touch any other field in the custom resource. - `"Webhook"`: API Server will call to an external webhook to do the conversion. Additional information is needed for this option. This requires spec.preserveUnknownFields to be false, and spec.conversion.webhook to be set.

=head2 webhook

webhook describes how to call the conversion webhook. Required when `strategy` is set to `"Webhook"`.

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartinez@capside.com> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by CAPSiDE.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut

==> IO-K8s-1.001.tar.gz: IO-K8s-1.001/lib/IO/K8s/ApiextensionsApiserver/Pkg/Apis/Apiextensions/V1/CustomResourceConversion.pm <==
package IO::K8s::ApiextensionsApiserver::Pkg::Apis::Apiextensions::V1::CustomResourceConversion;
# ABSTRACT: CustomResourceConversion describes how to convert different versions of a CR.
our $VERSION = '1.001';
use IO::K8s::Resource;

k8s strategy => Str, 'required';


k8s webhook => 'Apiextensions::V1::WebhookConversion';


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::ApiextensionsApiserver::Pkg::Apis::Apiextensions::V1::CustomResourceConversion - CustomResourceConversion describes how to convert different versions of a CR.

=head1 VERSION

version 1.001

=head2 strategy

strategy specifies how custom resources are converted between versions. Allowed values are: - `"None"`: The converter only change the apiVersion and would not touch any other field in the custom resource. - `"Webhook"`: API Server will call to an external webhook to do the conversion. Additional information is needed for this option. This requires spec.preserveUnknownFields to be false, and spec.conversion.webhook to be set.

=head2 webhook

webhook describes how to call the conversion webhook. Required when `strategy` is set to `"Webhook"`.

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartin@cpan.org> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Jose Luis Martinez.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
